@@ -13,7 +13,7 @@ from typedpy.structures import (
     FinalStructure,
     ImmutableField,
     unique,
-    AbstractStructure
+    AbstractStructure,
 )
 
 from typedpy.structures_reuse import (
@@ -85,7 +85,7 @@ from .serialization import (
     serialize_field,
     FunctionCall,
     deserialize_single_field,
-    HasTypes
+    HasTypes,
 )
 
 from .serialization_wrappers import (
@@ -117,4 +117,4 @@ from .versioned_mapping import convert_dict, Versioned
 
 from .commons import nested, deep_get, first_in, flatten, default_factories
 
-from .keysof import keys_of
\ No newline at end of file
+from .keysof import keys_of
